/*
 * Using this template application and the supplied ALC file you will be able to develop applications for
 * live MULTOS Trust Hub Dongles enabled using the Developer Community account (Issuer-ID 12000005) without
 * obtaining ALCs and ADCs from the MULTOS Key Management Authority.
 *
 * The supplied ALC (file) and the ADC (embedded into delete.c) are valid for an application with the following features
 *
 * 	AID:				F00000FF
 * 	Max code size:		25,000 bytes
 * 	Max data size:		10,000 bytes
 * 	Max session size:	2,000 bytes
 * 	Max DIR size		32 bytes
 * 	MAX FCI size		32 bytes
 * 	Access List:        Strong Crypto enabled.
 *
 * 	To load the application use hterm with the -alu and -alc options.
 * 		> hterm -serial COMx:i2c -alu myapp.alu -alc template_app_alc.ALR
 *
 * 	To delete the application use
 *		> hterm -serial COMx:i2c -selectaid F00000FF -apdu BB00000000
 *
 *  Once development is finished and the application is to be deployed to dongles enabled using your own issuer ID
 *  the following steps are required:
 *
 *  	1. Change the application's AID
 *  	2. Remove the delete.c source file and call to checkForDelete()
 *  	3. Register the application in the KMA
 *  	4. Obtain an ALC that will allow you to load your application to dongles with your issuer ID
 *
 * Remember that ADCs have to be requested individually for dongles. In some circumstances therefore you may
 * wish to replicate the mechanism in delete.c, with appropriate controls in place.
 *
 */

// Do not change these pragma settings
#pragma attribute("aid", "f0 00 00 ff")
#pragma attribute("name", "Myapp")
#pragma attribute("access_list", "0001")]

#include <multos.h>
#include <mi.h>

#pragma melpublic
union {
	BYTE abPublic[256];
} uPublic;

extern void checkForDelete (BYTE *pPub);

// Function to handle halts caused by the MULTOS O/S for different security reasons.
void abendHandler (void)
{
	SW1 = 0x9F;
	// Abend reason codes defined in mi.h, MI_ABEND_*
	SW2 = miAbendReason();
	multosExit();
}

void
main (void)
{
	/* Define local variables first - note automatically initialised to zero */
	BYTE abBuffer[8];
	BOOL fRunningInP22;
	BYTE abP22BuildNumber[] = {0x00, 0x02, 0x00, 0x02, 0x00, 0x29};

	/* Whilst developing your app, always include this as the first function call in main */
	checkForDelete(uPublic.abPublic);

	/* Note if the app is being run in a MULTOS ML5-P22 chip */
	if (multosGetConfigData(0x0A00,abBuffer))
	{
		fRunningInP22 = (multosCompareFixedLength(6,abP22BuildNumber,abBuffer) == MULTOS_BLOCK1_EQ_BLOCK2);
	}

	/* If running in P22, an abend handler can be specified */
	if (fRunningInP22)
	{
		miSetAbendFunction((WORD)abendHandler);
	}

	/* To debug an application in-chip, add a call to miDebuggingEnable() at the point you wish to start
	 * debugging from. Such calls MUST come after the call to checkForDelete() and MUST be removed from
	 * the final application.
	 *
	 * The 'sample' application shows one example of using the function.
	 */

	/* ========== Your actual application starts here ========== */

}


