#ifndef DEFINITIONS_H_
#define DEFINITIONS_H_
#include <multos.h>

// Instructions supported
#define INS_INIT_PIN		0x10
#define INS_VERIFY_PIN		0x11
#define INS_GEN_KEYPAIR		0x20
#define INS_SIGNATURE		0x21

// ISO Case definitions
#define CASE_NO_DATA		1
#define CASE_DATA_OUT		2
#define CASE_DATA_IN		3
#define CASE_DATA_INOUT		4

// PIN related values
#define PIN_NOT_INITIALISED	0x00
#define PIN_INITIALISED		0x02
#define PIN_VERIFIED		0xA5
#define PIN_UNVERIFIED		0x5A
#define PIN_VERIFICATION_OK		0x5AA5
#define PIN_VERIFICATION_NOK	0xA55A
#define PIN_LENGTH			0x05

// Key storage definitions
#define MODULUS_LENGTH ((WORD)256)
#define EXPONENT_LENGTH 1
#define KEYGEN_METHOD_DEFAULT 0x00
#define KEYGEN_MODE_BALANCED 0x01

typedef struct
{
	BYTE abPrivateKey[(MODULUS_LENGTH)/2 * 5];// Formatted as dp|dq|p|q|u
	BYTE abPublicKey[MODULUS_LENGTH];
	BYTE abExponent[EXPONENT_LENGTH];
} sRsa;

typedef struct {
	sRsa keyPair;
	BOOL fGenerated;
}sKeyStorage;

typedef struct {
	BYTE abPin[8];
	BYTE bPinLen;
	BYTE bPtc;
	BYTE bPtl;
} sInitPinData;

typedef struct {
	sInitPinData data;
	DWORD dwChecksum;
} sInitPinObject;

typedef union {
	BYTE 			abPublic[MODULUS_LENGTH];
	sInitPinData	pinData;
	BYTE			abPin[8];
} sPublic;


#endif /* DEFINITIONS_H_ */
